Coverage for scipy\interpolate\__init__.py: 0%

# Coverage for scipy\interpolate\__init__.py : 0%

## 15 statements 0 run 15 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 | """ ======================================== Interpolation (:mod:`scipy.interpolate`) ======================================== .. currentmodule:: scipy.interpolate Sub-package for objects used in interpolation. As listed below, this sub-package contains spline functions and classes, one-dimensional and multi-dimensional (univariate and multivariate) interpolation classes, Lagrange and Taylor polynomial interpolators, and wrappers for `FITPACK <http://www.netlib.org/dierckx/>`__ and DFITPACK functions. Univariate interpolation ======================== .. autosummary:: :toctree: generated/ interp1d BarycentricInterpolator KroghInterpolator barycentric_interpolate krogh_interpolate pchip_interpolate CubicHermiteSpline PchipInterpolator Akima1DInterpolator CubicSpline PPoly BPoly Multivariate interpolation ========================== Unstructured data: .. autosummary:: :toctree: generated/ griddata LinearNDInterpolator NearestNDInterpolator CloughTocher2DInterpolator Rbf interp2d For data on a grid: .. autosummary:: :toctree: generated/ interpn RegularGridInterpolator RectBivariateSpline .. seealso:: `scipy.ndimage.map_coordinates` Tensor product polynomials: .. autosummary:: :toctree: generated/ NdPPoly 1-D Splines =========== .. autosummary:: :toctree: generated/ BSpline make_interp_spline make_lsq_spline Functional interface to FITPACK routines: .. autosummary:: :toctree: generated/ splrep splprep splev splint sproot spalde splder splantider insert Object-oriented FITPACK interface: .. autosummary:: :toctree: generated/ UnivariateSpline InterpolatedUnivariateSpline LSQUnivariateSpline 2-D Splines =========== For data on a grid: .. autosummary:: :toctree: generated/ RectBivariateSpline RectSphereBivariateSpline For unstructured data: .. autosummary:: :toctree: generated/ BivariateSpline SmoothBivariateSpline SmoothSphereBivariateSpline LSQBivariateSpline LSQSphereBivariateSpline Low-level interface to FITPACK functions: .. autosummary:: :toctree: generated/ bisplrep bisplev Additional tools ================ .. autosummary:: :toctree: generated/ lagrange approximate_taylor_polynomial pade .. seealso:: `scipy.ndimage.map_coordinates`, `scipy.ndimage.spline_filter`, `scipy.signal.resample`, `scipy.signal.bspline`, `scipy.signal.gauss_spline`, `scipy.signal.qspline1d`, `scipy.signal.cspline1d`, `scipy.signal.qspline1d_eval`, `scipy.signal.cspline1d_eval`, `scipy.signal.qspline2d`, `scipy.signal.cspline2d`. ``pchip`` is an alias of `PchipInterpolator` for backward compatibility (should not be used in new code). """ from __future__ import division, print_function, absolute_import from .interpolate import * from .fitpack import * # New interface to fitpack library: from .fitpack2 import * from .rbf import Rbf from .polyint import * from ._cubic import * from .ndgriddata import * from ._bsplines import * from ._pade import * __all__ = [s for s in dir() if not s.startswith('_')] from scipy._lib._testutils import PytestTester test = PytestTester(__name__) del PytestTester # Backward compatibility pchip = PchipInterpolator